@@ -77,6 +77,19 @@ start_server {tags {"introspection"}} {
         $rd close
     }
 
+    test {MONITOR can log commands issued by functions} {
+        r function load replace {#!lua name=test
+            redis.register_function('test', function() return redis.call('set', 'foo', 'bar') end)
+        }
+        set rd [redis_deferring_client]
+        $rd monitor
+        $rd read ;# Discard the OK
+        r fcall test 0
+        assert_match {*fcall*test*} [$rd read]
+        assert_match {*lua*"set"*"foo"*"bar"*} [$rd read]
+        $rd close
+    }
+
     test {MONITOR supports redacting command arguments} {
         set rd [redis_deferring_client]
         $rd monitor
